@@ -70,14 +70,18 @@ init (NstPlugin *plugin)
 	dbus_g_proxy_call (object, "DefaultAdapter", &e,
 			   G_TYPE_INVALID, G_TYPE_STRING, &adapter, G_TYPE_INVALID);
 	if (e != NULL) {
-		const char *name;
 
-		name = dbus_g_error_get_name (e);
+		if (e->domain == DBUS_GERROR &&
+                    e->code == DBUS_GERROR_REMOTE_EXCEPTION) {
+			const char *name;
 
-		/* No adapter */
-		if (g_str_equal (name, "org.bluez.Error.NoSuchAdapter") != FALSE) {
-			g_error_free (e);
-			return FALSE;
+			name = dbus_g_error_get_name (e);
+
+			/* No adapter */
+			if (g_str_equal (name, "org.bluez.Error.NoSuchAdapter") != FALSE) {
+				g_error_free (e);
+				return FALSE;
+			}
 		}
 
 		g_warning ("Couldn't get default bluetooth adapter: %s",
@@ -211,23 +215,7 @@ remote_device_found (DBusGProxy *object,
 		     const char *address, guint class, int rssi,
 		     GtkListStore *store)
 {
-	GError *e = NULL;
-	const char *name;
-
-	dbus_g_proxy_call (object, "GetRemoteName", &e,
-			   G_TYPE_STRING, address, G_TYPE_INVALID,
-			   G_TYPE_STRING, &name, G_TYPE_INVALID);
-	if (e != NULL) {
-		const char *name;
-
-		name = dbus_g_error_get_name (e);
-		if (g_str_equal (name, "org.bluez.Error.RequestDeferred") != FALSE) {
-			add_phone_to_list (store, NULL, address);
-		}
-		g_error_free (e);
-	} else {
-		add_phone_to_list (store, name, address);
-	}
+	add_phone_to_list (store, NULL, address);
 }
 
 static void
@@ -270,6 +258,8 @@ remote_device_disappeared (DBusGProxy *object,
 static void
 start_device_scanning (GtkListStore *store)
 {
+	GError *e = NULL;
+
 	dbus_g_proxy_add_signal (object, "DiscoveryStarted", G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (object, "DiscoveryStarted",
 				     G_CALLBACK (discovery_started), NULL, NULL);
@@ -299,8 +289,13 @@ start_device_scanning (GtkListStore *store)
 	dbus_g_proxy_connect_signal (object, "DiscoveryCompleted",
 				     G_CALLBACK (discovery_completed), NULL, NULL);
 
-	dbus_g_proxy_call (object, "DiscoverDevices",
+	dbus_g_proxy_call (object, "DiscoverDevices", &e,
 			   G_TYPE_INVALID, G_TYPE_INVALID);
+	if (e != NULL) {
+		g_warning ("Couldn't start discovery: %s: %s",
+			   dbus_g_error_get_name (e), e->message);
+		g_error_free (e);
+	}
 }
 
 static GtkWidget*
